"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installRemoteContentSources = exports.getRemoteContentSources = void 0;
const url_1 = require("url");
const crypto_1 = __importDefault(require("crypto"));
const axios_1 = __importDefault(require("axios"));
const cms_core_1 = require("@stackbit/cms-core");
const getRemoteContentSources = async ({ siteId, teamId, projectId, netlifyAccessToken, apiSecret, logger, baseURL }) => {
    try {
        const headers = {
            'Content-Type': 'application/json',
            Authorization: `Bearer ${apiSecret ?? netlifyAccessToken}`
        };
        let urlPath = 'core/site-extensions-config';
        if (netlifyAccessToken) {
            headers['x-nf-request-id'] = crypto_1.default.randomBytes(16).toString('hex');
        }
        else {
            urlPath = `${urlPath}/${projectId}`;
        }
        const url = new url_1.URL(urlPath, baseURL);
        url.searchParams.set('configuration_type', 'create');
        url.searchParams.set('site_id', siteId);
        url.searchParams.set('team_id', teamId);
        const response = await (0, axios_1.default)(url.toString(), { headers });
        return response.data;
    }
    catch (error) {
        logger.debug('Error fetching remote content sources', { error });
        return [];
    }
};
exports.getRemoteContentSources = getRemoteContentSources;
const installRemoteContentSources = async ({ extensions, rootDir, logger }) => {
    const modulesToInstall = extensions.map((extension, index) => `${extension.integrationSlug}-connector@${extension.sourceUrl}?v=${Math.random()}-${index}`);
    const result = extensions.map((extension) => ({
        id: extension.id,
        config: extension.config,
        path: `${rootDir}/.stackbit/.cache/remote-content-sources/node_modules/${extension.integrationSlug}-connector/netlify-create.js`
    }));
    const runCommand = (0, cms_core_1.getCommandRunner)({ env: process.env });
    try {
        await runCommand('npm', ['install', ...modulesToInstall, '--no-save', '--prefix', '.stackbit/.cache/remote-content-sources', '--exact'], {
            env: process.env,
            cwd: rootDir,
            logger
        });
        return result;
    }
    catch (error) {
        logger.error(`Error installing remote content sources: ${modulesToInstall.join(',')}`, error);
        return [];
    }
};
exports.installRemoteContentSources = installRemoteContentSources;
//# sourceMappingURL=remote-content-source.js.map